@@ -14,7 +14,6 @@ pub use imp::fs::Advice;
 /// [Linux]: https://man7.org/linux/man-pages/man2/posix_fadvise.2.html
 #[inline]
 #[doc(alias = "posix_fadvise")]
-pub fn fadvise<Fd: AsFd>(fd: &Fd, offset: u64, len: u64, advice: Advice) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fadvise(fd, offset, len, advice)
+pub fn fadvise<Fd: AsFd>(fd: Fd, offset: u64, len: u64, advice: Advice) -> io::Result<()> {
+    imp::fs::syscalls::fadvise(fd.as_fd(), offset, len, advice)
 }
