@@ -18,11 +18,10 @@ pub use imp::fs::StatxFlags;
 /// [Linux]: https://man7.org/linux/man-pages/man2/statx.2.html
 #[inline]
 pub fn statx<P: path::Arg, Fd: AsFd>(
-    dirfd: &Fd,
+    dirfd: Fd,
     path: P,
     flags: AtFlags,
     mask: StatxFlags,
 ) -> io::Result<Statx> {
-    let dirfd = dirfd.as_fd();
-    path.into_with_z_str(|path| imp::fs::syscalls::statx(dirfd, path, flags, mask))
+    path.into_with_z_str(|path| imp::fs::syscalls::statx(dirfd.as_fd(), path, flags, mask))
 }
