@@ -10,22 +10,24 @@ mod write_sockaddr;
 pub(crate) mod ext;
 pub(crate) mod syscalls;
 pub use addr::SocketAddrStorage;
-#[cfg(not(windows))]
+#[cfg(unix)]
 pub use addr::SocketAddrUnix;
-pub(crate) use read_sockaddr::{read_sockaddr, read_sockaddr_os};
+pub(crate) use read_sockaddr::{
+    initialize_family_to_unspec, maybe_read_sockaddr_os, read_sockaddr, read_sockaddr_os,
+};
 pub use send_recv::{RecvFlags, SendFlags};
 pub use types::{AcceptFlags, AddressFamily, Protocol, Shutdown, SocketFlags, SocketType, Timeout};
 pub(crate) use write_sockaddr::{encode_sockaddr_v4, encode_sockaddr_v6, write_sockaddr};
 
 /// Return the offset of the `sun_path` field of `sockaddr_un`.
-#[cfg(not(windows))]
+#[cfg(unix)]
 #[inline]
 pub(crate) fn offsetof_sun_path() -> usize {
     let z = c::sockaddr_un {
         #[cfg(any(
             target_os = "dragonfly",
-            target_os = "ios",
             target_os = "freebsd",
+            target_os = "ios",
             target_os = "macos",
             target_os = "netbsd",
             target_os = "openbsd"
@@ -33,8 +35,8 @@ pub(crate) fn offsetof_sun_path() -> usize {
         sun_len: 0_u8,
         #[cfg(any(
             target_os = "dragonfly",
-            target_os = "ios",
             target_os = "freebsd",
+            target_os = "ios",
             target_os = "macos",
             target_os = "netbsd",
             target_os = "openbsd"
@@ -42,8 +44,8 @@ pub(crate) fn offsetof_sun_path() -> usize {
         sun_family: 0_u8,
         #[cfg(not(any(
             target_os = "dragonfly",
-            target_os = "ios",
             target_os = "freebsd",
+            target_os = "ios",
             target_os = "macos",
             target_os = "netbsd",
             target_os = "openbsd"
@@ -51,8 +53,8 @@ pub(crate) fn offsetof_sun_path() -> usize {
         sun_family: 0_u16,
         #[cfg(any(
             target_os = "dragonfly",
-            target_os = "ios",
             target_os = "freebsd",
+            target_os = "ios",
             target_os = "macos",
             target_os = "netbsd",
             target_os = "openbsd"
@@ -60,8 +62,8 @@ pub(crate) fn offsetof_sun_path() -> usize {
         sun_path: [0; 104],
         #[cfg(not(any(
             target_os = "dragonfly",
-            target_os = "ios",
             target_os = "freebsd",
+            target_os = "ios",
             target_os = "macos",
             target_os = "netbsd",
             target_os = "openbsd"
